@@ -1,13 +1,21 @@
+"""Implement a function to describe a schema in human readable text."""
+
 from .schema import Node, Atom, AtomType, Record, Tuple
 from .visitor import Visitor
-from .misc import closest, lev_dist
+from .misc import closest, lev_dist, Result
 
 
 def describe(schema, selects=()):
+    """Describe in human readable format :code:`schema`.
+
+    :param schema: The schema to describe.
+    :param selects: (optional, :code:`()`) a path into
+        schema to describe a sub-tree element only.
+    """
     res = select(schema, selects)
 
     if not res:
-        i = res.err
+        i = res.error
 
         if i == 0:
             raise KeyError(f"There is no {selects[0]} field in this schema.")
@@ -19,7 +27,7 @@ def describe(schema, selects=()):
     if selects != ():
         print(".".join(selects) + ":")
 
-    for s in Describer.describe(res.val):
+    for s in Describer.describe(res.value):
         print(s)
 
 
@@ -41,9 +49,13 @@ def select(schema, selects, index=0):
 
 
 class Describer(Visitor):
+    """A visitor that implement description.
+
+    You should probably be using :func:`describe` instead.
+    """
     @classmethod
     def describe(cls, schema):
-        """Show the visit"""
+        "Generate a set lines describing schema."
         yield from cls().describe_node(schema)
 
     def visit_atom(self, atom, indent=0):
@@ -132,30 +144,15 @@ class Describer(Visitor):
         yield from self.visit(value, indent=indent + 1)
 
 
-class Result:
-    def __init__(self, valid, val, err):
-        self.val = val
-        self.err = err
-        self.valid = valid
-
-    @classmethod
-    def error(cls, err):
-        return cls(False, None, err)
-
-    @classmethod
-    def ok(cls, val):
-        return cls(True, val, None)
-
-    def __bool__(self):
-        return self.valid
-
-
 def search(schema, name):
+    "Search for name into schema."
     likely = sorted(Searcher.search(schema, name))
     return [".".join(p) for _, p in likely]
 
 
 class Searcher(Visitor):
+    "A visitor implementing the search."
+
     @classmethod
     def search(cls, schema, name):
         """Show the visit"""
