@@ -1,3 +1,5 @@
+"The core definition of a schema."
+
 from dataclasses import dataclass
 from typing import Optional, List, Dict, Any
 from enum import Enum
@@ -68,6 +70,8 @@ class Node:
 
 
 class AtomType(Enum):
+    "Kind of atomic value."
+
     INT = 0
     FLOAT = 1
     STR = 2
